@@ -1,4 +1,4 @@
-# Copyright 2022 Tier IV, Inc.
+# Copyright 2023 iwatake2222
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,11 +16,11 @@ Test graph_layout module
 """
 
 import networkx as nx
-from dear_ros_node_viewer.graph_layout import place_node_by_group, align_layout
+from src.dear_ros_node_viewer.graph_layout import place_node_by_group, align_layout
 
 
 def test_graph_layout():
-    graph = nx.DiGraph()
+    graph = nx.MultiDiGraph()
     nx.add_path(graph, ['"/3"', '"/5"', '"/4"', '"/1"', '"/0"', '"/2"'])
 
     group_setting = {
